==> smartdoc-1.0.0.20020701.zip: src/jp/gr/java_conf/jaba2/xml/relax/expanded/EValueSlot.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2002  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.xml.relax.expanded;

import java.util.*;
import org.w3c.dom.*;
import jp.gr.java_conf.jaba2.xml.relax.cooked.*;

/**
 * EValueSlot
 *
 * @since   Apr. 19, 2002
 * @version Jun. 29, 2002
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class EValueSlot extends ENode implements IEOccurs {
    private String text_;
    private String xmlType_;

    public EValueSlot(CValue value) {
	super("value");
	text_ = value.getText();
	xmlType_ = value.getType();
    }

    public EValueSlot(EValueSlot slot) {
	super(slot);
	text_ = slot.text_;
	xmlType_ = slot.xmlType_;
    }

    public String getText() {
	return (text_);
    }

    public String getType() {
	return (xmlType_);
    }

    public boolean enter(IEVisitor visitor) {
	return (visitor.enter(this));
    }

    public void leave(IEVisitor visitor) {
	visitor.leave(this);
    }
}

==> smartdoc-1.0.1.20030714.zip: src/jp/gr/java_conf/jaba2/xml/relax/expanded/EValueSlot.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2002  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.xml.relax.expanded;

import java.util.*;
import org.w3c.dom.*;
import jp.gr.java_conf.jaba2.xml.relax.cooked.*;

/**
 * EValueSlot
 *
 * @since   Apr. 19, 2002
 * @version Jul. 12, 2002
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class EValueSlot extends ENode implements IEOccurs {
    private String text_;
    private String xmlType_;

    public EValueSlot(CValue value) {
	super("value");
	text_ = value.getText();
	xmlType_ = value.getType();
	if (xmlType_ == null) {
	    xmlType_ = "token";
	}
	_setup();
    }

    public EValueSlot(EValueSlot slot) {
	super(slot);
	text_ = slot.text_;
	xmlType_ = slot.xmlType_;
	_setup();
    }

    public EValueSlot(String text) {
	text_ = text;
	xmlType_ = "token";
	_setup();
    }

    public EValueSlot(String text, String type) {
	text_ = text;
	xmlType_ = type;
	_setup();
    }

    private void _setup() {
	setAttribute("text", text_);
	setAttribute("type", xmlType_);
    }

    public String getText() {
	return (text_);
    }

    public String getType() {
	return (xmlType_);
    }

    public boolean enter(IEVisitor visitor) {
	return (visitor.enter(this));
    }

    public void leave(IEVisitor visitor) {
	visitor.leave(this);
    }
}
